MiniAVFFIInputPlatform class

FFI implementation of MiniInputPlatformInterface.

Inheritance
  • Object
  • MiniInputPlatformInterface
  • MiniAVFFIInputPlatform

Constructors

MiniAVFFIInputPlatform()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addGamepadChangeListener(MiniAVDeviceChangeListener listener) → void Function()
Subscribe to gamepad add/remove notifications.
override
createContext() Future<MiniInputContextPlatformInterface>
Create an input capture context.
override
enumerateGamepads() Future<List<MiniAVDeviceInfo>>
Enumerate available gamepad devices.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited